package com.miya.fastcashier.ui

import android.content.Context
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import androidx.viewpager2.adapter.FragmentStateAdapter
import com.google.android.material.tabs.TabLayoutMediator
import com.miya.fastcashier.R
import com.miya.fastcashier.beans.ViewPayOrderData
import com.miya.fastcashier.databinding.ActivitySearchOrderBinding
import com.miya.fastcashier.databinding.FragmentSearchOrderBinding
import com.miya.fastcashier.databinding.ItemSearchOrderListBinding
import com.miya.fastcashier.utils.MiYaPayPlantformPayWayEnum
import com.miya.fastcashier.utils.clickWithTrigger

/**
 * 查单列表
 */
class SearchOrderActivity : BaseActivity() {
    private lateinit var binding: ActivitySearchOrderBinding

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivitySearchOrderBinding.inflate(LayoutInflater.from(this))
        setContentView(binding.root)
        binding.title.tvBack.clickWithTrigger { finish() }
        binding.title.ivBack.clickWithTrigger { finish() }

        binding.vpPage.adapter = object : FragmentStateAdapter(this) {
            override fun getItemCount(): Int {
                return 2
            }

            override fun createFragment(position: Int): Fragment {
                return when (position) {
                    0 -> SearchOrderFragment(MiYaPayPlantformPayWayEnum.MiyaPayType.WEIXIN)
                    else -> SearchOrderFragment(MiYaPayPlantformPayWayEnum.MiyaPayType.ALIPAY)
                }
            }
        }


        TabLayoutMediator(
            binding.tlIndicator,
            binding.vpPage
        ) { tab, position ->
            when (position) {
                0 -> tab.text = "微信"
                1 -> tab.text = "支付宝"
                else -> tab.text = ""
            }
        }.attach()


    }

}


class SearchOrderFragment(payType: MiYaPayPlantformPayWayEnum.MiyaPayType) : Fragment() {
    private var binding: FragmentSearchOrderBinding? = null

    private lateinit var adapter: SearchOrderListAdapter
    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentSearchOrderBinding.inflate(inflater, container, false)
        return binding!!.root
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        if (activity == null) {
            return
        }
        val act = requireActivity()
        binding?.run {
            adapter = SearchOrderListAdapter(act, arrayListOf())
            rvContent.layoutManager = LinearLayoutManager(act, LinearLayoutManager.VERTICAL, false)
            rvContent.adapter = adapter
            rvContent.addOnScrollListener(object : RecyclerView.OnScrollListener() {
                override fun onScrolled(recyclerView: RecyclerView, dx: Int, dy: Int) {
                    super.onScrolled(recyclerView, dx, dy)
                }

                override fun onScrollStateChanged(recyclerView: RecyclerView, newState: Int) {
                    super.onScrollStateChanged(recyclerView, newState)
                }
            })
        }
    }

    override fun onDestroyView() {
        binding = null
        super.onDestroyView()
    }
}

class SearchOrderListAdapter(
    val context: Context,
    private val list: MutableList<ViewPayOrderData>
) :
    RecyclerView.Adapter<SearchOrderViewHolder>() {
    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): SearchOrderViewHolder {
        return SearchOrderViewHolder(
            LayoutInflater.from(parent.context)
                .inflate(R.layout.item_search_order_list, parent, false)
        )
    }

    override fun onBindViewHolder(holder: SearchOrderViewHolder, position: Int) {
        holder.setData(list[position])
    }

    override fun getItemCount(): Int {
        return list.size
    }

}

class SearchOrderViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {
    private val binding: ItemSearchOrderListBinding = ItemSearchOrderListBinding.bind(itemView)

    fun setData(data: ViewPayOrderData) {
        binding.tvDate.text = data.chanelOrderTradeTime
    }

}